@@ -1258,6 +1258,103 @@ class APITests(BaseTests):
             }), content_type="application/json", HTTP_AUTHORIZATION=auth)
         self.assertResponse(response, 201)
 
+        response = self.client.post(reverse('socrates_api:firewall_ruleset_list'), data=json.dumps({
+                'name': 'ruleset_range1',
+                'rules': [
+                    {
+                        'type': 'ingress',
+                        'protocol': 'tcp',
+                        'source_addresses': [
+                            {'vrf': 0, 'address': '10.0.0.0', 'length': 8},
+                        ],
+                        'destination_ports': [{'start': 9000, 'end': 9090}],
+                    },
+                    {
+                        'type': 'egress',
+                        'protocol': 'tcp',
+                        'destination_addresses': [
+                            {'address_group': 'testgroup'},
+                            {'vrf': 0, 'address': '10.0.1.12', 'length': 32},
+                            {'vrf': 0, 'address': '10.0.1.13', 'length': 32},
+                        ],
+                        'destination_ports': [443],
+                    },
+                ]
+            }), content_type="application/json", HTTP_AUTHORIZATION=auth)
+        self.assertResponse(response, 201)
+
+        response = self.client.post(reverse('socrates_api:firewall_ruleset_list'), data=json.dumps({
+                'name': 'ruleset_faulty1',
+                'rules': [
+                    {
+                        'type': 'ingress',
+                        'protocol': 'tcp',
+                        'source_addresses': [
+                            {'vrf': 0, 'address': '10.0.0.0', 'length': 8},
+                        ],
+                        'destination_ports': [{'start': 8080, 'end': '8090'}],
+                    },
+                    {
+                        'type': 'egress',
+                        'protocol': 'tcp',
+                        'destination_addresses': [
+                            {'address_group': 'testgroup'},
+                            {'vrf': 0, 'address': '10.0.1.12', 'length': 32},
+                        ],
+                        'destination_ports': [443],
+                    },
+                ]
+            }), content_type="application/json", HTTP_AUTHORIZATION=auth)
+        self.assertResponse(response, 400)
+
+        response = self.client.post(reverse('socrates_api:firewall_ruleset_list'), data=json.dumps({
+                'name': 'ruleset_faulty2',
+                'rules': [
+                    {
+                        'type': 'ingress',
+                        'protocol': 'tcp',
+                        'source_addresses': [
+                            {'vrf': 0, 'address': '10.0.0.0', 'length': 8},
+                        ],
+                        'destination_ports': [{'start': 8443}],
+                    },
+                    {
+                        'type': 'egress',
+                        'protocol': 'tcp',
+                        'destination_addresses': [
+                            {'address_group': 'testgroup'},
+                            {'vrf': 0, 'address': '10.0.1.12', 'length': 32},
+                        ],
+                        'destination_ports': [443],
+                    },
+                ]
+            }), content_type="application/json", HTTP_AUTHORIZATION=auth)
+        self.assertResponse(response, 400)
+
+        response = self.client.post(reverse('socrates_api:firewall_ruleset_list'), data=json.dumps({
+                'name': 'ruleset_faulty3',
+                'rules': [
+                    {
+                        'type': 'ingress',
+                        'protocol': 'tcp',
+                        'source_addresses': [
+                            {'vrf': 0, 'address': '10.0.0.0', 'length': 8},
+                        ],
+                        'destination_ports': [{'start': 41000, 'end': 40000}],
+                    },
+                    {
+                        'type': 'egress',
+                        'protocol': 'tcp',
+                        'destination_addresses': [
+                            {'address_group': 'testgroup'},
+                            {'vrf': 0, 'address': '10.0.1.12', 'length': 32},
+                        ],
+                        'destination_ports': [443],
+                    },
+                ]
+            }), content_type="application/json", HTTP_AUTHORIZATION=auth)
+        self.assertResponse(response, 400)
+
         response = self.client.patch(reverse('socrates_api:network_detail', kwargs={
                 'vrf': 0, 'network': '10.0.0.0', 'length': 24
             }), data=json.dumps({
